==> com.liferay.dynamic.data.mapping.data.provider.instance-3.0.13-sources-commercial.jar: com/liferay/dynamic/data/mapping/data/provider/instance/internal/DDMStorageTypesDataProvider.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.dynamic.data.mapping.data.provider.instance.internal;

import com.liferay.dynamic.data.mapping.data.provider.DDMDataProvider;
import com.liferay.dynamic.data.mapping.data.provider.DDMDataProviderRequest;
import com.liferay.dynamic.data.mapping.data.provider.DDMDataProviderResponse;
import com.liferay.dynamic.data.mapping.storage.DDMStorageAdapterTracker;
import com.liferay.portal.kernel.language.LanguageUtil;
import com.liferay.portal.kernel.util.KeyValuePair;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import java.util.Set;

import javax.servlet.http.HttpServletRequest;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Marcellus Tavares
 */
@Component(
	immediate = true,
	property = "ddm.data.provider.instance.id=ddm-storage-types",
	service = DDMDataProvider.class
)
public class DDMStorageTypesDataProvider implements DDMDataProvider {

	@Override
	public DDMDataProviderResponse getData(
		DDMDataProviderRequest ddmDataProviderRequest) {

		List<KeyValuePair> keyValuePairs = new ArrayList<>();

		Set<String> storageTypes =
			ddmStorageAdapterTracker.getDDMStorageAdapterTypes();

		Optional<HttpServletRequest> httpServletRequestOptional =
			ddmDataProviderRequest.getParameterOptional(
				"httpServletRequest", HttpServletRequest.class);

		HttpServletRequest httpServletRequest =
			httpServletRequestOptional.orElse(null);

		for (String storageType : storageTypes) {
			if (httpServletRequest == null) {
				keyValuePairs.add(new KeyValuePair(storageType, storageType));

				continue;
			}

			keyValuePairs.add(
				new KeyValuePair(
					storageType,
					LanguageUtil.get(
						httpServletRequest, storageType + "[stands-for]",
						LanguageUtil.get(httpServletRequest, storageType))));
		}

		DDMDataProviderResponse.Builder builder =
			DDMDataProviderResponse.Builder.newBuilder();

		builder.withOutput("Default-Output", keyValuePairs);

		return builder.build();
	}

	@Override
	public Class<?> getSettings() {
		throw new UnsupportedOperationException();
	}

	@Reference
	protected DDMStorageAdapterTracker ddmStorageAdapterTracker;

}

==> com.liferay.dynamic.data.mapping.data.provider.instance-4.0.9-sources-commercial.jar: com/liferay/dynamic/data/mapping/data/provider/instance/internal/DDMStorageTypesDataProvider.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.dynamic.data.mapping.data.provider.instance.internal;

import com.liferay.dynamic.data.mapping.data.provider.DDMDataProvider;
import com.liferay.dynamic.data.mapping.data.provider.DDMDataProviderRequest;
import com.liferay.dynamic.data.mapping.data.provider.DDMDataProviderResponse;
import com.liferay.dynamic.data.mapping.storage.DDMStorageAdapterTracker;
import com.liferay.dynamic.data.mapping.storage.StorageType;
import com.liferay.portal.kernel.language.LanguageUtil;
import com.liferay.portal.kernel.util.KeyValuePair;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import java.util.Set;

import javax.servlet.http.HttpServletRequest;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Marcellus Tavares
 */
@Component(
	immediate = true,
	property = "ddm.data.provider.instance.id=ddm-storage-types",
	service = DDMDataProvider.class
)
public class DDMStorageTypesDataProvider implements DDMDataProvider {

	@Override
	public DDMDataProviderResponse getData(
		DDMDataProviderRequest ddmDataProviderRequest) {

		List<KeyValuePair> keyValuePairs = new ArrayList<>();

		Set<String> storageTypes =
			ddmStorageAdapterTracker.getDDMStorageAdapterTypes();

		Optional<HttpServletRequest> httpServletRequestOptional =
			ddmDataProviderRequest.getParameterOptional(
				"httpServletRequest", HttpServletRequest.class);

		HttpServletRequest httpServletRequest =
			httpServletRequestOptional.orElse(null);

		for (String storageType : storageTypes) {
			if (storageType.equals(StorageType.JSON.getValue())) {
				continue;
			}

			if (httpServletRequest == null) {
				keyValuePairs.add(new KeyValuePair(storageType, storageType));

				continue;
			}

			keyValuePairs.add(
				new KeyValuePair(
					storageType,
					LanguageUtil.get(
						httpServletRequest, storageType + "[stands-for]",
						LanguageUtil.get(httpServletRequest, storageType))));
		}

		DDMDataProviderResponse.Builder builder =
			DDMDataProviderResponse.Builder.newBuilder();

		builder.withOutput("Default-Output", keyValuePairs);

		return builder.build();
	}

	@Override
	public Class<?> getSettings() {
		throw new UnsupportedOperationException();
	}

	@Reference
	protected DDMStorageAdapterTracker ddmStorageAdapterTracker;

}
